@@ -2,7 +2,7 @@
 
 set -e
 
-if [[ "$PACKAGER" == "conda" ]]; then
+if [[ "$PACKAGER" == conda* ]]; then
     source activate $VIRTUALENV
 elif [[ "$PACKAGER" == "pip" ]]; then
     # we actually use conda to install the base environment:
@@ -14,4 +14,4 @@ fi
 set -x
 PYTHONPATH="." python continuous_integration/display_versions.py
 
-pytest -vlrxXs --junitxml=$JUNITXML --cov=threadpoolctl
+pytest -vlrxXs -W error -k "$TESTS" --junitxml=$JUNITXML --cov=threadpoolctl
